@@ -187,8 +187,8 @@ static void ctk_event_class_init(CtkEventClass *ctk_event_class)
     MAKE_SIGNAL(NV_CTRL_GVO_SUPPORTED);
     MAKE_SIGNAL(NV_CTRL_GVO_SYNC_MODE);
     MAKE_SIGNAL(NV_CTRL_GVO_SYNC_SOURCE);
-    MAKE_SIGNAL(NV_CTRL_GVO_OUTPUT_VIDEO_FORMAT);
-    MAKE_SIGNAL(NV_CTRL_GVO_INPUT_VIDEO_FORMAT);
+    MAKE_SIGNAL(NV_CTRL_GVIO_REQUESTED_VIDEO_FORMAT);
+    MAKE_SIGNAL(NV_CTRL_GVIO_DETECTED_VIDEO_FORMAT);
     MAKE_SIGNAL(NV_CTRL_GVO_DATA_FORMAT);
     MAKE_SIGNAL(NV_CTRL_GVO_DISPLAY_X_SCREEN);
     MAKE_SIGNAL(NV_CTRL_GVO_COMPOSITE_SYNC_INPUT_DETECTED);
@@ -200,9 +200,9 @@ static void ctk_event_class_init(CtkEventClass *ctk_event_class)
     MAKE_SIGNAL(NV_CTRL_GVO_SYNC_DELAY_LINES);
     MAKE_SIGNAL(NV_CTRL_GVO_INPUT_VIDEO_FORMAT_REACQUIRE);
     MAKE_SIGNAL(NV_CTRL_GVO_GLX_LOCKED);
-    MAKE_SIGNAL(NV_CTRL_GVO_VIDEO_FORMAT_WIDTH);
-    MAKE_SIGNAL(NV_CTRL_GVO_VIDEO_FORMAT_HEIGHT);
-    MAKE_SIGNAL(NV_CTRL_GVO_VIDEO_FORMAT_REFRESH_RATE);
+    MAKE_SIGNAL(NV_CTRL_GVIO_VIDEO_FORMAT_WIDTH);
+    MAKE_SIGNAL(NV_CTRL_GVIO_VIDEO_FORMAT_HEIGHT);
+    MAKE_SIGNAL(NV_CTRL_GVIO_VIDEO_FORMAT_REFRESH_RATE);
     MAKE_SIGNAL(NV_CTRL_GVO_X_SCREEN_PAN_X);
     MAKE_SIGNAL(NV_CTRL_GVO_X_SCREEN_PAN_Y);
     MAKE_SIGNAL(NV_CTRL_GPU_OVERCLOCKING_STATE);
@@ -270,6 +270,9 @@ static void ctk_event_class_init(CtkEventClass *ctk_event_class)
     MAKE_SIGNAL(NV_CTRL_SLI_MOSAIC_MODE_AVAILABLE);
     MAKE_SIGNAL(NV_CTRL_GVO_ENABLE_RGB_DATA);
     MAKE_SIGNAL(NV_CTRL_IMAGE_SHARPENING_DEFAULT);
+    MAKE_SIGNAL(NV_CTRL_GVI_NUM_PORTS);
+    MAKE_SIGNAL(NV_CTRL_FRAMELOCK_SYNC_DELAY_RESOLUTION);
+    MAKE_SIGNAL(NV_CTRL_GPU_POWER_MIZER_MODE);
 
 #undef MAKE_SIGNAL
     
@@ -280,7 +283,7 @@ static void ctk_event_class_init(CtkEventClass *ctk_event_class)
      * knows about.
      */
 
-#if NV_CTRL_LAST_ATTRIBUTE != NV_CTRL_IMAGE_SHARPENING_DEFAULT
+#if NV_CTRL_LAST_ATTRIBUTE != NV_CTRL_GPU_POWER_MIZER_MODE
 #warning "There are attributes that do not emit signals!"
 #endif
 
@@ -299,7 +302,7 @@ static void ctk_event_class_init(CtkEventClass *ctk_event_class)
     MAKE_STRING_SIGNAL(NV_CTRL_STRING_NVIDIA_DRIVER_VERSION);
     MAKE_STRING_SIGNAL(NV_CTRL_STRING_DISPLAY_DEVICE_NAME);
     MAKE_STRING_SIGNAL(NV_CTRL_STRING_TV_ENCODER_NAME);
-    MAKE_STRING_SIGNAL(NV_CTRL_STRING_GVO_FIRMWARE_VERSION);
+    MAKE_STRING_SIGNAL(NV_CTRL_STRING_GVIO_FIRMWARE_VERSION);
     MAKE_STRING_SIGNAL(NV_CTRL_STRING_CURRENT_MODELINE);
     MAKE_STRING_SIGNAL(NV_CTRL_STRING_ADD_MODELINE);
     MAKE_STRING_SIGNAL(NV_CTRL_STRING_DELETE_MODELINE);
@@ -321,7 +324,7 @@ static void ctk_event_class_init(CtkEventClass *ctk_event_class)
     MAKE_STRING_SIGNAL(NV_CTRL_STRING_TWINVIEW_XINERAMA_INFO_ORDER);
     MAKE_STRING_SIGNAL(NV_CTRL_STRING_SLI_MODE);
     MAKE_STRING_SIGNAL(NV_CTRL_STRING_PERFORMANCE_MODES);
-    MAKE_STRING_SIGNAL(NV_CTRL_STRING_GVO_VIDEO_FORMAT_NAME);
+    MAKE_STRING_SIGNAL(NV_CTRL_STRING_GVIO_VIDEO_FORMAT_NAME);
 #undef MAKE_STRING_SIGNAL
 
 #if NV_CTRL_STRING_LAST_ATTRIBUTE != NV_CTRL_STRING_GVO_VIDEO_FORMAT_NAME
@@ -347,10 +350,11 @@ static void ctk_event_class_init(CtkEventClass *ctk_event_class)
     MAKE_BINARY_SIGNAL(NV_CTRL_BINARY_DATA_FRAMELOCKS_USED_BY_GPU);
     MAKE_BINARY_SIGNAL(NV_CTRL_BINARY_DATA_GPUS_USING_VCSC);
     MAKE_BINARY_SIGNAL(NV_CTRL_BINARY_DATA_VCSCS_USED_BY_GPU);
+    MAKE_BINARY_SIGNAL(NV_CTRL_BINARY_DATA_GPUS_USED_BY_LOGICAL_XSCREEN);
 
 #undef MAKE_BINARY_SIGNAL
     
-#if NV_CTRL_BINARY_DATA_LAST_ATTRIBUTE != NV_CTRL_BINARY_DATA_VCSCS_USED_BY_GPU
+#if NV_CTRL_BINARY_DATA_LAST_ATTRIBUTE != NV_CTRL_BINARY_DATA_GPUS_USED_BY_LOGICAL_XSCREEN
 #warning "There are attributes that do not emit signals!"
 #endif
 
